import {async, ComponentFixture, TestBed} from '@angular/core/testing';

import {CalibratorComponent} from './calibrator.component';
import {Component, ViewChild} from "@angular/core";
import {Calibrator} from "../../model/calibrator";
import {Flux} from "../../model/flux";
import {CalibratorsService} from "../../services/calibrators.service";
import {ReactiveFormsModule} from "@angular/forms";
import {By} from "@angular/platform-browser";
import {of} from "rxjs";
import {BrowserAnimationsModule} from "@angular/platform-browser/animations";

// mock a host container so we can input bind to the unit under test
@Component({
  template: '<app-calibrator [calibrator]="calibrator" [flux]="flux"></app-calibrator>'
})
class HostComponent {
  calibrator: Calibrator = {
    fluxes: [],
    id: 2,
    name: "J0004+2019",
    polarization: [],
    sctCatalogId: 16632,
    sctId: 18640,
    type: null
  };

  flux: Flux = {
    flux: 0.295,
    frequency: 3.058,
    id: 2,
    observingDate: 1485725362000,
    spectralIndex: 0.134,
    uvMax: null,
    uvMin: null
  };
  @ViewChild(CalibratorComponent, /* TODO: add static flag */ {}) calibratorComponent: CalibratorComponent;
}

describe('CalibratorComponent', () => {
  let component: HostComponent;
  let fixture: ComponentFixture<HostComponent>;
  let calibratorServiceSpy: { saveCalibratorFlux: jasmine.Spy }; // we'll use a spy in place of the real service

  beforeEach(async(() => {
    calibratorServiceSpy = jasmine.createSpyObj('CalibratorsService', ['saveCalibratorFlux']);
    TestBed.configureTestingModule({
      declarations: [HostComponent, CalibratorComponent],
      providers: [{provide: CalibratorsService, useValue: calibratorServiceSpy}],
      imports: [ReactiveFormsModule, BrowserAnimationsModule]
    })
      .compileComponents();
  }));

  beforeEach(() => {
    fixture = TestBed.createComponent(HostComponent);
    component = fixture.componentInstance;
    calibratorServiceSpy = TestBed.get(CalibratorsService);
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('should populate form with flux input values', () => {

    component.calibratorComponent.detailsExposed = true;

    fixture.detectChanges(); // ngOnInit

    let frequencyEl: HTMLInputElement = fixture.debugElement.query(By.css('#frequency')).nativeElement;
    expect(parseFloat(frequencyEl.value)).toEqual(component.flux.frequency, 'frequency set in form');

    let fluxEl: HTMLInputElement = fixture.debugElement.query(By.css('#flux')).nativeElement;
    expect(parseFloat(fluxEl.value)).toEqual(component.flux.flux, 'flux set in form');

    let spectralIndexEl: HTMLInputElement = fixture.debugElement.query(By.css('#spectralIndex')).nativeElement;
    expect(parseFloat(spectralIndexEl.value)).toEqual(component.flux.spectralIndex, 'spectralIndex set in form');

  });

  it('should call saveCalibratorFlux() on service when form is submitted', () => {
    calibratorServiceSpy.saveCalibratorFlux.and.returnValue(of('success'));
    component.calibratorComponent.detailsExposed = true;

    fixture.detectChanges(); // ngOnInit

    let submitButton: HTMLButtonElement = fixture.debugElement.query(By.css('.saveFlux')).nativeElement;
    submitButton.click();

    fixture.detectChanges();

    expect(calibratorServiceSpy.saveCalibratorFlux.calls.count()).toBe(1, 'called service to save');
  });

});
