import {Component, OnDestroy, OnInit} from '@angular/core';
import {Subscription} from "rxjs";
import {CalibratorsService} from "../services/calibrators.service";
import {Calibrator} from "../model/calibrator";
import {AlertService} from "../services/alert.service";
import {faPlus} from "@fortawesome/free-solid-svg-icons";

@Component({
  selector: 'app-calibrators',
  templateUrl: './calibrators.component.html',
  styleUrls: ['./calibrators.component.scss']
})
export class CalibratorsComponent implements OnInit, OnDestroy {

  public calibrators$: Subscription;
  public calibrators: Array<Calibrator>;
  public faPlus = faPlus;

  constructor(private calibratorService: CalibratorsService, private alertService: AlertService) {
  }

  ngOnInit() {
    this.alertService.info('Getting calibrators');
    this.calibrators$ = this.calibratorService.getCalibrators().subscribe((c: Array<Calibrator>) => {
      if (c && c.length > 0) {
        this.alertService.success('Calibrators retrieved');
        this.calibrators = c;
      } else {
        this.alertService.error('Calibrators could not be retrieved');
      }
    });
  }

  ngOnDestroy(): void {
    if (this.calibrators$) {
      this.calibrators$.unsubscribe();
    }
  }

}
